#!/bin/sh
#
# Created 14 July, 1999
# Last Modified, 23 March 2000
# Lance Spitzner <lance@spitzner.net>
#
# This script installs the FW-1 alert.sh
# Intrusion Detection script, as documented
# at http://www.enteract.com/~lspitz/intrusion.html
#

dir=`pwd`

cat <<EOF 

Welcome to the FW1 IDS installation script.  This
script will install and configure your IDS script
customized for you.  Just follow the prompts below.

You are currently in the $dir directory. Is this
the directory you want to install the scripts in?
EOF

echo "Answer [y,n] --> \c"
read ans


###### If answer is no, exit out
if [ $ans != y ];then
	cat <<EOF

Opps!  You must run this script in the directory you 
want to install the IDS package.  Please cd to the 
directory you want to install the IDS package,
untar the alert.tar package there, and then execute
this install script again.

Thank you :)

EOF

exit 5

fi

###### Looks like they said yes, lets keep going.

cat <<EOF

Great, lets keep going.  What I am going to do
is create the log files that will be used by 
our alert.sh script.


EOF
sleep 5

###### Create archive.log file for storing ALL FW log entries
echo "I am now creating the file \"alert.archive\""
echo "This file will store every FW Log entry"
echo "produced by the FW1 alerts."

touch alert.archive
cat <<EOF > alert.archive
#
# This file is the result of the script alert.sh
# The purpose of this file is to keep a entry for
# every connection logged by the User Defined Alert.
#
# Every port scanned is logged to this file
# To get a basic overview of what systems have scanned
# your network, please refer to the file alert.uniq
#
EOF


sleep 5

###### Create alert.uniq file for storing one entry for each
###### system that scans your network.
echo "\nI am now creating the file \"alert.uniq\""
echo "This file will store one entry for each system"
echo "that scans your network."

touch alert.uniq
cat <<EOF > alert.uniq
#
# This file is the result of the script alert.sh.
# The purpose of this file is to keep a single entry
# of every system that has scanned this network.  
# 
# Only the first connection/service is logged to this file
# To review every port that was scanned by each Source, review
# the file archive.log
#
EOF
sleep 5

###### Create alert.log file for temporarily storing
###### all logged alerts for one day.
cat <<EOF

I am now creating the file "alert.log"  This file 
will log all alerts for the day.  This file is
how "alert.sh" counts how many times the source
scanned you in one day.  This protects you from
Denial of Service attacks.
EOF

touch alert.log
sleep 5

##### Create rotate.sh file for clearing out
##### alert.log every day and storing the logs
##### to alert.archive.

cat <<EOF

I am now creating the file "rotate.sh"  This
file will rotate "alert.log" every day.  Be 
sure to add the following entry to your
cronjob.

55 23 * * * $dir/rotate.sh
EOF


cat <<EOF > rotate.sh
#!/bin/ksh
#
# Created 17 Feb, 1999
# Lance Spitzner lance@spitzner.net
#
# This file clears daily the alert.log file and
# archives it to alert.archive
#

cat $dir/alert.log >> $dir/alert.archive

cp /dev/null $dir/alert.log

exit

EOF

chmod 750 $dir/rotate.sh
sleep 5


### Determine OS, set MAIL variable
echo "\nDetermining OS to set MAIL variable"

os=`uname`

echo "Looks like you are running $os"

if [ $os = "SunOS" ];then
        cat $dir/alert.sh | sed -e "s/MAIL=mail/MAIL=mailx/g" > $dir/tmp.txt
        mv $dir/tmp.txt $dir/alert.sh
	echo "Setting MAIL variable to mailx\n" 
else
	echo "Setting MAIL variable to mail\n"

fi

sleep 5 

cat <<EOF


----- INSTALLATION SUCCESSFULL -----

Congratulations, we are all done!  Your FW-1 alert
script has been properly setup.  Make sure you
have completed the following five steps.

1.  Ensure you have an alert rule in your firewall 
rule base that points to the User Defined Alert.

2.  Make sure you have your User Defined Alert
defined in the Firewall GUI as follows:
$dir/alert.sh

3.  Add the following entry to your cronjob:
55 23 * * * $dir/rotate.sh

4.  Edit the alert.sh script.  You only need to
review the customize options at the top of the 
script. 

5.  Once you have everthing configured and
ready to go, test out your configuration by
running the "test.sh" script.


If you have any questions or problems, be sure
to review the latest on-line documentation at 
http://www.enteract.com/~lspitz/intrusion.html.
I would love to hear your comments/suggestions
about either the installation or alert script.

Thanks! Enjoy, and happy hunting :)

Lance Spitzner, lance@spitzner.net
http://www.enteract.com/~lspitz/papers.html

EOF

